@@ -1,8 +1,10 @@
 hdda <-
 function(data,cls,model='AkjBkQkDk',graph=FALSE,d="Cattell",threshold=0.2,show=TRUE,scaling=FALSE){
 	Mod<-c("AKJBKQKDK","AKBKQKDK","ABKQKDK","AKJBQKDK","AKBQKDK","ABQKDK","AKJBKQKD","AKBKQKD","ABKQKD","AKJBQKD","AKBQKD","ABQKD","AJBQD","ABQD","DBEST","BEST")
-	model=toupper(model)
+	if (is.numeric(model)) model=na.omit(Mod[model])
+	else model=toupper(model)
 	if (any(Mod==model)==0) stop("Error : invalid model name\n",.Call=FALSE)
+	else if (length(model)!=1) stop("Error : model can't be a vector\n",.Call=FALSE)
 	else if (is.numeric(threshold)==0) stop("Error : the parameter 'threshold' must a double strictly within ]0,1[\n",.Call=FALSE)
 	else if (threshold<=0 | threshold>=1) stop("Error : the parameter 'threshold' must be strictly within ]0,1[\n",.Call=FALSE)
 	else if (any(is.na(data))) stop("Error : NA values are not supported\n",.Call=FALSE)
@@ -35,19 +37,19 @@ function(data,cls,model='AkjBkQkDk',graph=FALSE,d="Cattell",threshold=0.2,show=T
 			else n<-0
 			if (show) cat("\t  Model  \t    BIC\n")
 			e[[1]]<-pck_hdda_prms(data,z,Mod[1+n],threshold,graph,d,u)
-			BIC[1]<-pck_hdda_bic(data,Mod[1+n],e[[1]])
+			BIC[1]<-pck_hdda_bic(data,Mod[1+n],e[[1]],1)
 			if (show) cat('\t',Mod2[1+n],'\t',BIC[1],'\n')
 			for (i in 2:6) {
 				e[[i]]<-pck_hdda_prms_bis(data,Mod[i+n],e[[1]])
-				BIC[i]<-pck_hdda_bic(data,Mod[i+n],e[[i]])
+				BIC[i]<-pck_hdda_bic(data,Mod[i+n],e[[i]],1)
 				if (show) cat('\t',Mod2[i+n],'\t',BIC[i],'\n')
 			}
 			if (model=='DBEST') {
 				e[[7]]<-pck_hdda_prms(data,z,Mod[13],threshold,FALSE,d,u)
-				BIC[[7]]<-pck_hdda_bic(data,Mod[13],e[[7]])
+				BIC[[7]]<-pck_hdda_bic(data,Mod[13],e[[7]],1)
 				if (show) cat('\t',Mod2[13],'\t',BIC[7],'\n')
 				e[[8]]<-pck_hdda_prms_bis(data,Mod[14],e[[7]])
-				BIC[[8]]<-pck_hdda_bic(data,Mod[14],e[[8]])
+				BIC[[8]]<-pck_hdda_bic(data,Mod[14],e[[8]],1)
 				if (show) cat('\t',Mod2[14],'\t',BIC[8],'\n')
 			}
 			prms<-e[[which.max(BIC)]]
@@ -66,7 +68,7 @@ function(data,cls,model='AkjBkQkDk',graph=FALSE,d="Cattell",threshold=0.2,show=T
 				graph=FALSE
 			}
 			prms<-pck_hdda_prms(data,z,model,threshold,graph,d,u)
-			prms$BIC<-pck_hdda_bic(data,model,prms)
+			prms$BIC<-pck_hdda_bic(data,model,prms,1)
 			prms$scaling<-scaling
 			class(prms)<-'hdc'
 			prms
